import poja.sed as sed


def set_sentry(dsn, dir, exclude):

    sentry_deps = """
    implementation 'io.sentry:sentry-spring-boot-starter-jakarta:7.4.0'
    <?java-deps>
    """
    sentry_env_vars = f"""
        SENTRY_DSN: !Sub '{{{{resolve:ssm:{dsn}}}}}'
        SENTRY_ENVIRONMENT: !Ref Env
        <?java-env-vars>
    """
    sentry_test_env = """
        registry.add("sentry.dsn", () -> "https://public@sentry.example.com/1");
        registry.add("sentry.environment", () -> "dummy");
    """

    sed.find_replace(dir, "<?sentry-test-env>", sentry_test_env, exclude)
    sed.find_replace(dir, "<?java-deps>", sentry_deps, exclude)
    sed.find_replace(dir, "<?java-env-vars>", sentry_env_vars, exclude)



import os
from fnmatch import fnmatch


def find_replace(directory, find, replace, exclude_pattern):
    for path, dirs, files in os.walk(os.path.abspath(directory)):
        for filename in [f for f in files if not fnmatch(f, exclude_pattern)]:
            filepath = os.path.join(path, filename)
            with open(filepath, errors="ignore") as f:
                s = f.read()
            s = s.replace(find, replace)
            with open(filepath, "w") as f:
                f.write(s)


def remove_line_by_keyword(filename, keyword):
    with open(filename, "r") as file:
        lines = file.readlines()

    with open(filename, "w") as file:
        for line in lines:
            if keyword not in line:
                file.write(line)
